tkmilan.model
=============

.. automodule:: tkmilan.model

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      CP_Compound
      GUI_STATES
      GUI_STATES_common
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Binding
      BindingGlobal
      BindingTag
      CP
      Direction
      FileType
      FileTypes
      GridCoordinates
      GridSize
      GuiState
      GuiState_Tk
      MixinBinding
      NotebookTab
      PixelSize
      TextElement
      TextElement_br
      TextElement_span
      Timeout
      TimeoutIdle
      TreeColumn
      TreeElement
      VState
      WState
      WStyle
      WidgetDynamicState
   
   

   
   
   



